package com.servicemall.basis.micro;

import com.alibaba.fastjson.JSONObject;
import com.servicemall.systemcommon.data.Constants;
import com.servicemall.systemcommon.data.ErrorEnum;
import com.servicemall.systemcommon.data.ValidCheckException;
import com.servicemall.systemcommon.util.JsonUtil;
import io.swagger.annotations.*;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;
import team.bangbang.common.data.Pagination;
import team.bangbang.common.data.response.DataResponse;
import team.bangbang.common.data.response.ResponseBase;
import team.bangbang.common.net.http.HttpClient;
import team.bangbang.common.net.http.ResponseHandler;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;

/**
 * 基础数据 - 微服务
 * @author 帮帮组
 * @version 1.0  2020-12-08
 */
@Api(tags = {"basis"})
@ApiResponses(value={@ApiResponse(code=200, message="请求的服务不存在")})
@RestController
@CrossOrigin(allowCredentials = "true", allowedHeaders = "*", origins = "*", maxAge = 3600)
@RequestMapping("/microservice/basis")
public final class BasisMicro {
    /**************************************************************************
     * ！！除非设计、指导人员有特别说明，否则此处不得随意增加、修改、删除！！
     * －－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－－
     *
     *************************************************************************/

    /**
     * 省市接口
     */
    @ApiOperation(value = "获取省市信息", notes = "省市信息树形结构", httpMethod = "POST")
    @PostMapping(value = "/province", produces = {MediaType.APPLICATION_JSON_VALUE}, consumes = {MediaType.APPLICATION_JSON_VALUE})
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "json", value = "入参格式:{}", dataType = "string")
    })
    public ResponseBase province(@RequestBody String json) {
        DataResponse<Object> result = new DataResponse<>();
        try {
            ResponseHandler responseHandler = new HttpClient().get("http://161.189.8.153:8889/v1/wx/provinces");
            result.setData(responseHandler.toJSONObject().getJSONArray("options"));
            result.setMessage("成功");
            return result;
        } catch (IOException e) {
            return new ResponseBase(ErrorEnum.E_404.getCode(), ErrorEnum.E_404.getMessage());
        } catch (ValidCheckException e) {
            return new ResponseBase(e.getCode(), e.getMessage());
        }
    }

    /**
     * 经销商接口
     */
    @ApiOperation(value = "获取经销商信息", notes = "经销商信息", httpMethod = "POST")
    @PostMapping(value = "/dealers", produces = {MediaType.APPLICATION_JSON_VALUE}, consumes = {MediaType.APPLICATION_JSON_VALUE})
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "json", value = "入参格式:{}", dataType = "string")
    })
    public ResponseBase dealers(@RequestBody String json) {
        DataResponse<Map<String, Object>> result = new DataResponse<Map<String, Object>>();

        try {
            ResponseHandler responseHandler = new HttpClient().get("http://161.189.8.153:8889/v1/wx/dealers");
            Map<String, Object> datas = new HashMap<String, Object>();
            JSONObject remoteJson=responseHandler.toJSONObject();
            datas.put("list", remoteJson.getJSONArray("rows"));
            JSONObject paginationJson=remoteJson.getJSONObject("pagination");
            Pagination pagination = new Pagination();
            pagination.setRecordCount(paginationJson.getIntValue("total"));
            pagination.setMaxResults(20);//每页条数，接口方默认20
            pagination.setPageNo(paginationJson.getIntValue("page"));
            datas.put("pagination", pagination);

            result.setData(datas);
            result.setMessage("成功");
            return result;
        } catch (IOException e) {
            return new ResponseBase(ErrorEnum.E_404.getCode(), ErrorEnum.E_404.getMessage());
        } catch (ValidCheckException e) {
            return new ResponseBase(e.getCode(), e.getMessage());
        }
    }

    /**
     * 车型车系接口
     */
    @ApiOperation(value = "获取车型车系信息", notes = "车型车系信息", httpMethod = "POST")
    @PostMapping(value = "/productManagement/getSeriesModels", produces = {MediaType.APPLICATION_JSON_VALUE}, consumes = {MediaType.APPLICATION_JSON_VALUE})
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", name = "json", value = "入参格式:{}", dataType = "string")
    })
    public ResponseBase getSeriesModels(@RequestBody String json) {
        DataResponse<Object> result = new DataResponse<>();
        try {
            ResponseHandler responseHandler = new HttpClient().get("http://161.189.8.153:8889/v1/product_management/get_series_models");
            result.setData(responseHandler.toJSONObject().get("data"));
            result.setMessage("成功");
            return result;
        } catch (IOException e) {
            return new ResponseBase(ErrorEnum.E_404.getCode(), ErrorEnum.E_404.getMessage());
        } catch (ValidCheckException e) {
            return new ResponseBase(e.getCode(), e.getMessage());
        }
    }

}
